@@ -313,6 +313,10 @@ class TBDFile {
 	bool parseArchFlowSequence(Token archName) {
 		expectToken("archs");
 
+		// <rdar://problem/22268737> x86_64h fails to link against text based stubs
+		if ( archName == "x86_64h" )
+			archName = "x86_64";
+
 		bool foundArch = false;
 		parseFlowSequence([&](Token name) {
 			if ( name == archName )
